@@ -30,6 +30,7 @@ from . import PlotStyles
 from .ModelClasses import ModelItem
 from Tigger.Coordinates import angular_dist_pos_angle, DEG
 from functools import reduce
+import functools
 
 
 class ModelTag(ModelItem):
@@ -55,7 +56,9 @@ class ModelTagSet(ModelItem):
 
     def getAll(self):
         all = list(self.tags.values())
-        all.sort(lambda a, b: cmp(a.name, b.name))
+        from past.builtins import cmp
+        from functools import cmp_to_key
+        all.sort(key=cmp_to_key(lambda a, b: cmp(a.name(), b.name())))
         return all
 
     def addNames(self, names):
@@ -73,8 +76,8 @@ class ModelTagSet(ModelItem):
             markup += "mdlattr=%s " % attrname
         markup += ">"
         # write mandatory attributes
-        for name, tt in self.tags.items():
-            markup += self.renderAttrMarkup(name, tt, tag="TR", mandatory=True)
+        for name, tt in list(self.tags.items()):
+            markup += self.renderAttrMarkup(name, tt, tags="TR", mandatory=True)
         # closing tag
         markup += "</%s>" % tag
         return markup
@@ -109,7 +112,6 @@ class Source(ModelItem):
         if iapp is not None:
             return iapp
         else:
-            print(self.flux)
             return getattr(self.flux, 'I', 0.)
 
     def get_attr(self, attr, default=None):
@@ -190,12 +192,12 @@ class SkyModel(ModelItem):
 
     # Bitflags for the 'what' argument of the updated() signal below.
     # These indicate what exactly has been updated:
-    UpdateSourceList = 1;  # source list changed
-    UpdateSourceContent = 2;  # source attributes have changed
-    UpdateTags = 4;  # tags have been changed
-    UpdateGroupVis = 8;  # visibility of a grouping (group.style.show_list attribute) has changed
-    UpdateGroupStyle = 16;  # plot style of a grouping has changed
-    UpdateSelectionOnly = 32;  # (in combination with UpdateSourceContent): update only affects currently selected sources
+    UpdateSourceList = 1  # source list changed
+    UpdateSourceContent = 2  # source attributes have changed
+    UpdateTags = 4  # tags have been changed
+    UpdateGroupVis = 8  # visibility of a grouping (group.style.show_list attribute) has changed
+    UpdateGroupStyle = 16  # plot style of a grouping has changed
+    UpdateSelectionOnly = 32  # (in combination with UpdateSourceContent): update only affects currently selected sources
     UpdateAll = UpdateSourceList + UpdateSourceContent + UpdateTags + UpdateGroupVis + UpdateGroupStyle
 
     def emitUpdate(self, what=UpdateSourceContent, origin=None):
@@ -283,7 +285,7 @@ class SkyModel(ModelItem):
         if 'default' in self.plotstyles:
             defstyle = PlotStyles.BaselinePlotStyle.copy()
             defstyle.update(self.plotstyles['default'])
-            defstyle.apply = 1000;  # apply at lowest priority
+            defstyle.apply = 1000  # apply at lowest priority
         else:
             defstyle = self.plotstyles['default'] = PlotStyles.BaselinePlotStyle
         self.defgroup = Source.Grouping("all sources", func=lambda src: True, sources=self.sources, style=defstyle)
@@ -338,7 +340,9 @@ class SkyModel(ModelItem):
         # get list of styles from  groupings to which this source belongs
         styles = [group.style for group in self.groupings if group.func(src)]
         # sort in order of priority (high apply to low apply)
-        styles.sort(lambda a, b: cmp(b.apply, a.apply))
+        from past.builtins import cmp
+        from functools import cmp_to_key
+        styles.sort(key=cmp_to_key(lambda a, b: cmp(b.apply, a.apply)))
         # "show_plot" attribute: if at least one group is showing explicitly, show
         # else if at least one group is hiding explicitly, hide
         # else use default setting
@@ -348,7 +352,7 @@ class SkyModel(ModelItem):
         elif show and min(show) == PlotStyles.ShowNot:
             show = False
         else:
-            show = bool(style0.show_plot)
+            show = True
         if not show:
             return None, None
         # sort styles
@@ -426,7 +430,9 @@ class SkyModel(ModelItem):
         if not selection or selection.lower() == "all":
             return self.sources
         # sort by brightness
-        srclist0 = sorted(self.sources, lambda a, b: cmp(b.brightness(), a.brightness()))
+        from past.builtins import cmp
+        from functools import cmp_to_key
+        srclist0 = sorted(self.sources, key=cmp_to_key(lambda a, b: cmp(b.brightness(), a.brightness())))
         all = set([src.name for src in srclist0])
         srcs = set()
         for ispec, spec in enumerate(re.split("\s+|,", selection)):
